@@ -236,3 +236,17 @@ void PuntateMain::on_stream13_2_clicked()
     process.start("sh /opt/serviziopubblico/script/p14.sh");
     process.waitForFinished();
 }
+
+void PuntateMain::on_down15_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/d15.sh");
+    process.waitForFinished();
+}
+
+void PuntateMain::on_stream15_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/p15.sh");
+    process.waitForFinished();
+}
