@@ -76,6 +76,10 @@ private slots:
 
     void on_stream13_2_clicked();
 
+    void on_down15_clicked();
+
+    void on_stream15_clicked();
+
 private:
     Ui::PuntateMain *ui;
 };
